<?php

namespace Teknisa\FIN\Modules\ContaReceber\Factory;

use Doctrine\ORM\EntityManager;
use Financeiro\Entities\Boletreceber;
use Financeiro\Entities\Cnabrec;
use Teknisa\Libs\Util\DateUtil;
use Teknisa\Model\Financeiro\Entities\Logboletoremrec;

/**
 * Class RemessaReceberFactory
 * @package Teknisa\FIN\Modules\ContaReceber\Factory
 */
class RemessaReceberFactory {

    protected $entityManager;

    /**
     * @param EntityManager $entityManager
     */
    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    /**
     * Busca CNAB Receber
     * @param $nrorg
     * @param $cdempresa
     * @param $nrcnabrec
     * @return Cnabrec
     */
    public static function buscaCnabrec(
        $nrorg, $cdempresa, $nrcnabrec
    ){
        /** @var Cnabrec $cnabrec */
        $cnabrec = Cnabrec::findOneByNrorgAndCdempresaAndNrcnabrec(
            $nrorg, $cdempresa, $nrcnabrec
        );

        return $cnabrec;
    }

    /**
     * Insere CNAB Receber
     * @param $nrorg
     * @param $cdempresa
     * @param $cdoperador
     * @param $dtcnabrec
     * @param $idtipcnabrec
     * @param $cdreducont
     * @param $cdbanco
     * @param $idopecnabrec
     * @return Cnabrec
     */
    public static function insereCnabRec(
        $nrorg, $cdempresa, $nrcnabrec, $cdoperador, $dtcnabrec, $idtipcnabrec,
        $cdreducont, $cdbanco, $cdreducontcobr, $idopecnabrec, $qtbolenvcnabrec,
        $vrtotbolcnabrec, $nrseqremessarec, $dsarqcnabrec
    ){
        /** @var Cnabrec $cnabrec */
        $cnabrec = New Cnabrec();
        $cnabrec->setNrorg($nrorg);
        $cnabrec->setCdempresa($cdempresa);
        $cnabrec->setNrcnabrec($nrcnabrec);
        $cnabrec->setCdoperador($cdoperador);
        $cnabrec->setDtcnabrec($dtcnabrec);
        $cnabrec->setIdtipcnabrec($idtipcnabrec);
        $cnabrec->setCdreducont($cdreducont);
        $cnabrec->setCdbanco($cdbanco);
        $cnabrec->setCdreducontcobr($cdreducontcobr);
        $cnabrec->setIdopecnabrec($idopecnabrec);
        $cnabrec->setQtbolenvcnabrec($qtbolenvcnabrec);
        $cnabrec->setVrtotbolcnabrec($vrtotbolcnabrec);
        $cnabrec->setNrseqremessarec($nrseqremessarec);
        $cnabrec->setDsarqcnabrec($dsarqcnabrec);
        $cnabrec->setDtinclusao(DateUtil::getDataAtual());
        $cnabrec->setDtultatu(DateUtil::getDataAtual());
        $cnabrec->setIdativo('S');

        return $cnabrec;
    }

    /**
     * Insere Log Boleto Remessa
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanbolrec
     * @param $nrcnabrec
     * @param $cdempresa
     * @param $cdoperador
     * @return Logboletoremrec
     */
    public static function insereLogBoletoRem(
        $nrorg, $cdfilial, $nrlanbolrec, $nrcnabrec, $cdempresa, $cdoperador
    ){
        /** @var Logboletoremrec $logboletoremrec */
        $logboletoremrec = New Logboletoremrec();
        $logboletoremrec->setNrorg($nrorg);
        $logboletoremrec->setCdfiliallogrec($cdfilial);
        $logboletoremrec->setNrlanbolreclog($nrlanbolrec);
        $logboletoremrec->setNrcnabrecretlog($nrcnabrec);
        $logboletoremrec->setCdempresalogrec($cdempresa);
        $logboletoremrec->setCdopelogrec($cdoperador);
        $logboletoremrec->setDtlogboletrrec(DateUtil::getDataAtual());
        $logboletoremrec->setDtinclusao(DateUtil::getDataAtual());

        return $logboletoremrec;
    }

    /**
     * Atualiza Boleto Receber
     * @param Boletreceber $boletreceber
     * @param $nrcnabrec
     * @return Boletreceber
     */
    public static function atualizaBoletreceber(
        Boletreceber $boletreceber, $nrcnabrec, $idsitucnabr, $idbolrecalter
    ){
        $boletreceber->setNrcnabrecrem($nrcnabrec);
        $boletreceber->setIdsitucnabr($idsitucnabr);
        $boletreceber->setIdbolrecalter($idbolrecalter);

        return $boletreceber;
    }

    /**
     * @param Cnabrec $cnabrec
     * @param $dsarqcnabrec
     * @return Cnabrec
     */
    public static function atualizaCnabrec(
        Cnabrec $cnabrec, $dsarqcnabrec
    ){
        $cnabrec->setDsarqcnabrec($dsarqcnabrec);

        return $cnabrec;
    }
    
    /**
     * Busca Log Boleto Remessa Receber
     * @param $nrorg
     * @param $cdfiliallogrec
     * @param $nrlanbolreclog
     * @param $cdempresalogrec
     * @param $nrcnabrecretlog
     * @return Logboletoremrec
     */
    public function buscaLogboletoremrec($nrorg, $cdfiliallogrec, $nrlanbolreclog, $cdempresalogrec, $nrcnabrecretlog){
        /** @var $params */
        $params = array();
        $params['nrorg']           = $nrorg;
        $params['cdfiliallogrec']  = $cdfiliallogrec;
        $params['nrlanbolreclog']  = $nrlanbolreclog;
        $params['cdempresalogrec'] = $cdempresalogrec;
        $params['nrcnabrecretlog'] = $nrcnabrecretlog;

        /** @var Logboletoremrec $logboletoremrec */
        $logboletoremrec = $this->entityManager->getRepository(Logboletoremrec::class)->findOneBy($params);

        return $logboletoremrec;
    }

}